@@ -7,7 +7,6 @@ from pathlib import Path
 import click
 import click_log
 
-from libratom.cli.cli import set_log_level_from_verbose
 from libratom.lib.download import download_files
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
@@ -20,6 +19,18 @@ CACHED_ENRON_DATA_DIR = Path("/tmp/libratom/test_data/RevisedEDRMv1_Complete")
 click_log.basic_config(logging.getLogger())
 
 
+def set_log_level_from_verbose(ctx, param, value):
+    if value > 1:
+        level = logging.DEBUG
+    elif value > 0:
+        level = logging.INFO
+    else:
+        # Default
+        level = logging.WARNING
+    logging.getLogger().setLevel(level)
+    return level
+
+
 @click.command(
     context_settings=CONTEXT_SETTINGS,
     help=f"Download edrm files into {CACHED_ENRON_DATA_DIR}/",
